{ config, pkgs, ... }:

{
  imports =
    [
    ../../base.nix
      ../../common/metrics-exporters.nix
      ./hardware-configuration.nix
      ./containers.nix
      ./vms.nix

      ./services/nginx
      ./services/metrics
  # TODO:
  # x Boot
  # x Mount ZFS
  # x Monitoring server
  # x Podman
  #    x Flame
  # - Transmission
  # - Jellyfin
  # - NFS exports
  # - FreeBSD VM
  # - Kali VM
  # - Kerberos / IPA
  ];

  boot = {
    zfs.extraPools = [ "tank" ];
    supportedFilesystems = [ "zfs" ];
    kernelPackages = config.boot.zfs.package.latestCompatibleLinuxPackages;
  };
  services.zfs.autoScrub.enable = true;

  networking = {
    hostName = "voyager";
    defaultGateway = "192.168.10.1";
    nameservers = [ "192.168.10.1" "1.1.1.1" ];
    interfaces.eno1.ipv4 = {
      addresses = [
      { address = "192.168.10.165"; prefixLength = 24; }
      ];
    };
    hostId = "8e84b235";
  };

  environment.variables = { EDITOR = "vim"; };
  environment.systemPackages = with pkgs; [
    ((vim_configurable.override {  }).customize{
     name = "vim";
     vimrcConfig.packages.myplugins = with pkgs.vimPlugins; {
     start = [ vim-nix vim-lastplace ];
     opt = [];
     };
     vimrcConfig.customRC = ''
     " your custom vimrc
     set number
     set relativenumber
     set nu rnu
     set signcolumn=number

     set hlsearch
     set smartcase
     set incsearch

     set autoindent
     set expandtab
     set shiftwidth=2
     set tabstop=2
     set smartindent
     set smarttab

     set ruler

     set undolevels=1000

     set nocompatible
     set backspace=indent,eol,start
     " Turn on syntax highlighting by default
     syntax on
     " ...
     '';
    }
  )
    zfs
    ];

  networking.firewall.allowedTCPPorts = [ 22 ];

  system.stateVersion = "22.11";
}

